@@ -15,7 +15,9 @@ class PreCheck:
             self.user_id = server_config["user_id"]
             self.user_password = server_config["user_password"]
             self.project_name = server_config["project_name"]
+            self.train_input_columns = server_config["train_input_columns"]
             self.train_do_name = server_config["train_do_name"]
+            self.inference_input_columns = server_config["inference_input_columns"]
             self.inference_do_name = server_config["inference_do_name"]
         except KeyError as e:
             print(f'Cannot found "{str(e)}" in server_config.yaml')
@@ -106,9 +108,18 @@ class PreCheck:
         result_data = res.data["dto"]["dataObjectInfoList"]
         for data in result_data:
             if data["name"] == self.train_do_name:
-                self.train_do_id = data["id"]
-                print("check is train do exist end.\n")
-                return
+                res = self.hyperdata_client.get_do_detail_info(self.auth, data["id"])
+                data_columns = [col_info["name"] for col_info in res.data["dto"]["colInfoList"]]
+                if (len(data_columns) == len(self.train_input_columns) and
+                        len(list(set(data_columns) & set(self.train_input_columns))) == len(data_columns)):
+                    print("check is train do exist end.\n")
+                    self.train_do_id = data["id"]
+                    return
+                else:
+                    print("train input columns are not matching with train_do.")
+                    print(f"train input columns: {str(self.train_input_columns)}")
+                    print(f"train do columns: {str(data_columns)}")
+                    raise Exception()
 
         print(f"cannot found train do")
         exit(1)
@@ -126,9 +137,18 @@ class PreCheck:
         result_data = res.data["dto"]["dataObjectInfoList"]
         for data in result_data:
             if data["name"] == self.inference_do_name:
-                self.inference_do_id = data["id"]
-                print("check is inference do exist end.\n")
-                return
+                res = self.hyperdata_client.get_do_detail_info(self.auth, data["id"])
+                data_columns = [col_info["name"] for col_info in res.data["dto"]["colInfoList"]]
+                if (len(data_columns) == len(self.inference_input_columns) and
+                        len(list(set(data_columns) & set(self.inference_input_columns))) == len(data_columns)):
+                    print("check is inference do exist end.\n")
+                    self.inference_do_id = data["id"]
+                    return
+                else:
+                    print("inference input columns are not matching with inference_do.")
+                    print(f"inference input columns: {str(self.inference_input_columns)}")
+                    print(f"inference do columns: {str(data_columns)}")
+                    raise Exception()
 
         print(f"cannot found inference do")
         exit(1)
